require 'arbor/client'
require 'arbor/query'
require 'arbor/serialiser_registry'
require 'active_support/inflector'
require 'arbor/errors'

module Arbor
  class << self
    def serialisers
      @serialisers ||= SerialiserRegistry.new
    end
  end

  RESOURCES = [:academic_calendar_dates, :academic_holidays, :academic_levels,
    :academic_level_memberships, :academic_level_registration_form_mappings,
    :academic_level_tutors, :academic_programmes, :academic_programme_instances,
    :academic_teaching_hours, :academic_units,
    :academic_unit_automatic_enrolments, :academic_unit_cohorts,
    :academic_unit_cohort_memberships, :academic_unit_curriculums,
    :academic_unit_enrolments, :academic_unit_leads, :academic_unit_tags,
    :academic_working_days, :academic_years, :achievement_levels,
    :achievement_level_sets, :additional_payment_reasons, :alerts, :allowances,
    :allowance_amounts, :applications, :application_settings,
    :application_withdrawal_reasons, :aspects, :aspect_sets, :assessments,
    :assessment_batches, :assessment_batch_targets, :assessment_derivations,
    :assessment_derivation_dependants, :assessment_templates,
    :assessment_template_assessments, :attendance_follow_ups, :attendance_marks,
    :attendance_patterns, :attendance_pattern_periods, :attendance_records,
    :attendance_register_types, :attendance_register_type_marks,
    :awarding_bodies, :awarding_body_staffs, :bank_details, :behaviours,
    :behavioural_contracts, :behavioural_contract_goals,
    :behavioural_contract_parties, :behavioural_contract_periods,
    :behavioural_incidents, :behavioural_incident_actions,
    :behavioural_incident_behaviours, :behavioural_incident_staff_involvements,
    :behavioural_incident_student_involvements, :behavioural_notes,
    :boarding_patterns, :boarding_statuses, :bookable_resource_periods,
    :business_roles, :business_role_assignments,
    :business_role_default_user_roles, :calendars, :calendar_entries,
    :calendar_entry_dates, :calendar_entry_mappings, :calendar_types, :cases,
    :center_numbers, :check_clearance_levels, :check_types,
    :child_protection_statuses, :child_protection_status_assignments,
    :collections, :communication_actions, :communication_tags, :companies,
    :company_staffs, :consents, :consent_types, :contents, :content_tags,
    :countries, :court_orders, :court_order_parties, :cover_arrangements,
    :cover_requirements, :curriculums, :curriculum_evidences, :curriculum_goals,
    :curriculum_grades, :curriculum_judgements, :curriculum_sections,
    :curriculum_stages, :curriculum_tiers, :custom_groups,
    :custom_group_memberships, :dashboards, :dashboard_kpis,
    :dashboard_sections, :data_check_errors, :data_check_error_related_entities,
    :data_export_errors, :data_export_error_tags, :data_item_subscriptions,
    :data_set_subscriptions, :detentions, :detention_sessions,
    :dietary_requirements, :dietary_requirement_types, :document_html_templates,
    :document_image_templates, :document_layouts, :education_plans,
    :education_plan_contributors, :eligibilities, :eligibility_records, :emails,
    :email_accounts, :email_account_access_permissions, :email_addresses,
    :email_drafts, :email_mailboxes, :email_parts, :email_recipients,
    :email_references, :email_senders, :email_statuses, :enrolment_modes,
    :ethnicities, :event_participants, :event_participant_invitations,
    :exceptions, :exclusion_reasons, :faculties, :faculty_members, :files,
    :genders, :grades, :grade_point_scales, :grade_point_scale_level_grade_sets,
    :grade_sets, :guardians, :guardian_consultations,
    :guardian_relationship_types, :hearing_tests, :houses, :house_memberships,
    :house_tutors, :hydrators, :identification_document_types, :identity_cards,
    :identity_card_readers, :immunizations, :immunization_types,
    :impairment_categories, :import_records, :in_care_statuses,
    :in_care_status_assignments, :intake_seasons,
    :intake_season_applicant_buckets, :intake_season_groups, :item_units, :kpis,
    :kpi_ranges, :kpi_targets, :kpi_values, :languages, :language_abilities,
    :layout_object_types, :letters, :letter_drafts, :meals, :meal_patterns,
    :meal_prices, :meal_provisions, :meal_sessions,
    :meal_session_register_records, :meal_sittings,
    :meal_sitting_automatic_attendee_targets, :medical_conditions,
    :medical_condition_medications, :medical_condition_types, :medical_events,
    :medical_event_types, :medical_institutions, :medical_institution_staffs,
    :medical_plans, :medical_relationship_types, :medications, :meetings,
    :meeting_notes, :meeting_topics, :message_draft_recipients, :model_bases,
    :motor_vehicles, :motor_vehicle_makes, :nationality_statuses,
    :next_of_kin_relationships, :notes, :notices, :operations, :pastoral_notes,
    :pay_scales, :pay_scale_grades, :pay_scale_grade_spinal_points,
    :pay_scale_spinal_points, :pay_scale_spinal_point_values,
    :permanent_exclusions, :persons, :person_checks, :person_former_names,
    :person_identification_documents, :person_impairments,
    :person_nationalities, :person_next_of_kins,
    :person_professional_qualifications, :person_training_courses,
    :person_transportation_methods, :point_awards, :point_award_categories,
    :point_award_scales, :point_award_totals, :positions,
    :position_business_roles, :postal_addresses, :postal_address_occupancies,
    :professional_qualification_classes, :professional_qualification_subjects,
    :professional_qualification_types, :progress_assessment_batches,
    :progress_assessment_batch_measurement_periods,
    :progress_assessment_batch_targets, :progress_measurement_periods,
    :qualification_aspects, :qualification_assessables,
    :qualification_assessable_instances, :qualification_awards,
    :qualification_award_level_types, :qualification_award_types,
    :qualification_centre_assessed_marks,
    :qualification_element_disallowed_combinations,
    :qualification_element_relationships, :qualification_element_series_links,
    :qualification_grades, :qualification_grade_sets,
    :qualification_incoming_messages, :qualification_learning_units,
    :qualification_predictions, :qualification_registrations,
    :qualification_registration_requests, :qualification_request_batches,
    :qualification_results, :qualification_schemes, :qualification_series,
    :qualification_special_arrangements,
    :qualification_special_arrangement_types, :qualification_timetable_sessions,
    :qualification_timetable_session_types, :qualification_time_windows,
    :qualification_time_window_collections, :registration_forms,
    :registration_form_memberships, :registration_form_tutors, :religions,
    :report_card_batches, :report_card_batch_targets,
    :report_card_batch_template_variables, :report_card_templates,
    :report_card_template_sections, :report_subscriptions, :rooms, :room_assets,
    :room_features, :room_room_assets, :room_room_features, :schools,
    :school_events, :school_event_types, :school_staffs,
    :school_trips, :schoolworks, :schoolwork_curriculum_goals,
    :schoolwork_types, :sending_profiles, :sen_events, :sen_event_outcomes,
    :sen_event_outcome_types, :sen_event_types, :sen_needs, :sen_need_types,
    :sen_notes, :sen_provisions, :sen_provision_linked_relationships,
    :sen_provision_types, :sen_statements, :sen_statuses,
    :sen_status_assignments, :sessions, :session_curriculum_goals,
    :session_room_asset_requirements, :session_room_feature_requirements,
    :session_streams, :session_stream_automatic_enrolments,
    :session_stream_enrolments, :session_stream_leads, :sites,
    :site_operating_periods, :site_operating_period_exceptions,
    :site_travel_times, :sms_messages, :sms_message_drafts, :sms_message_parts,
    :sms_message_statuses, :snippets, :snippet_availabilities, :staffs,
    :staff_absences, :staff_absence_categories, :staff_attendance_marks,
    :staff_attendance_records, :staff_contracts, :staff_contract_posts,
    :staff_contract_post_additional_payments, :staff_contract_post_allowances,
    :staff_contract_post_end_reasons, :staff_contract_post_rates,
    :staff_contract_post_salaries, :staff_contract_post_start_reasons,
    :staff_destinations, :staff_employment_types, :staff_origins,
    :staff_room_feature_requirements, :staff_working_periods, :students,
    :student_absence_notes, :student_assessments, :student_assessment_marks,
    :student_attendance_patterns, :student_guardian_relationships,
    :student_linked_relationships, :student_linked_relationship_types,
    :student_medical_relationships, :student_other_school_attendance_records,
    :student_progress_assessments, :student_progress_assessment_marks,
    :student_progress_baselines, :student_progress_goals, :student_report_cards,
    :student_report_card_marks, :student_report_card_sections,
    :student_room_feature_requirements, :student_schools, :student_schoolworks,
    :student_schoolwork_marks, :subjects, :superannuation_schemes,
    :superannuation_scheme_values, :tags, :taggings,
    :teaching_assistant_allocations, :telephone_calls, :telephone_numbers,
    :temporary_exclusions, :terms, :timetable_slots, :timetable_slot_staffs,
    :titles, :training_courses, :training_events, :transportation_methods,
    :triggers, :unenrolment_reasons, :universities, :university_staffs,
    :usage_log_entries, :users, :user_defined_fields, :user_defined_records,
    :user_notifications, :user_roles, :user_role_assignments, :vision_tests,
    :widgets, :widget_types, :workitems, :workitem_assignments,
    :"uk_dfe/upn_assignments", :changes, :attendance_registers,
    :academic_year_enrolments]
end
